#!/usr/bin/env python2.6
# encoding: utf-8
"""
__init__.py

Created by disko on 2010-08-28.
Copyright (c) 2010 binary punks. All rights reserved.
"""

# IMPORTS

import baker
import os
import os.path
import sys
import table
import terminal


# IMPLEMENTATION

@baker.command
def replace(pattern, replace, *files):
    """replace every occurance of <pattern> with <replace> in all filenames"""
    
    old_filenames = []
    new_filenames = []
    
    for f in files:
        oldname = f.split("/")[-1]
        old_filenames.append(oldname)
        
        newname  = oldname.replace(pattern, replace)
        new_filenames.append(newname)
    
    rename_tuples = [ t for t in zip(old_filenames, new_filenames) if t[0] != t[1] ]
    
    t = table.Table(rename_tuples)
    print "\n%s\n" % t.draw()
    
    yn = terminal.Terminal().requestSingleCharAnswerFromUser("Is this what you want?")
    
    if yn == "y":
        for names in zip(files, new_filenames):
            
            src = names[0]
            
            if not os.path.exists(src):
                print "No such file:", src
                continue
            
            directory_path = os.path.dirname(src)
            dst = os.path.join(directory_path, names[1])
            
            if dst == src:
                continue
            
            if os.path.exists(dst):
                print "Cannot rename '%s' to '%s': a file with the target name already exists." % (src, dst, )
                continue
            
            os.rename(src, dst)
        
        print "\ndone.\n"
    elif yn == "n":
        print "\naborted.\n"


@baker.command
def remove(pattern, *files):
    """removes every occurance of <pattern> from all filenames"""
    
    replace(pattern, "", *files)


def main():
    """main entry point"""
    
    try:
        baker.run()
    except baker.CommandError, e:
        print "\n%s\n" % e
        print "Run '%s -h' for help.\n" % os.path.split(sys.argv[0])[-1]


if __name__ == '__main__':
    main()



#!/usr/bin/env python2.6
# encoding: utf-8
"""
table.py

Created by disko on 2010-08-28.
Copyright (c) 2010 binary punks. All rights reserved.
"""

# IMPORTS

import texttable


# IMPLEMENTATION

class Table(texttable.Texttable):
    """Table for displaying rename operations (old filename => new filename)"""
    
    def __init__(self, rows):
        
        texttable.Texttable.__init__(self, max_width=0)
        
        self.set_deco(self.HEADER)
        self.header(("current filename", "=>", "new filename"))
        self.set_cols_align(("l", "c", "l"))
        
        for row in rows:
            self.add_row((row[0], "=>", row[1]))
        
    
    




#!/usr/bin/env python2.6
# encoding: utf-8
"""
terminal.py

Created by disko on 2010-08-28.
Copyright (c) 2010 binary punks. All rights reserved.
"""

# IMPORTS

import fcntl
import os
import sys
import termios


# CONFIGURATION

# IMPLEMENTATION

class Terminal(object):
    """Helper class for command line sessions"""
    
    def __init__(self):
        
        super(Terminal, self).__init__()
    
    
    def requestSingleCharAnswerFromUser(self, question="Are you sure (y/n)?", allowed_answers=["y", "n", ]):
        """Ask the user a question and wait for a valid (single char) answer"""
        
        fd = sys.stdin.fileno()
        
        oldterm = termios.tcgetattr(fd)
        newattr = termios.tcgetattr(fd)
        newattr[3] = newattr[3] & ~termios.ICANON & ~termios.ECHO
        termios.tcsetattr(fd, termios.TCSANOW, newattr)
        oldflags = fcntl.fcntl(fd, fcntl.F_GETFL)
        fcntl.fcntl(fd, fcntl.F_SETFL, oldflags | os.O_NONBLOCK)
        
        sys.stdout.write("%s (%s) " % (question, "/".join(allowed_answers), ))
        while True:
            try:
                answer = sys.stdin.read(1)
            except IOError:
                continue
            
            if answer in allowed_answers:
                break
        
        termios.tcsetattr(fd, termios.TCSAFLUSH, oldterm)
        fcntl.fcntl(fd, fcntl.F_SETFL, oldflags)
        
        print
        
        return answer
    
    




from setuptools import setup, find_packages
import os

version = '0.1'

setup(
    name                    = 'bp.rename',
    version                 = version,
    description             = "Command line script to make common file renaming operations easier",
    long_description        = open("README").read() + "\n" + open(os.path.join("docs", "HISTORY.txt")).read(),
    classifiers             = [
        "Development Status :: 2 - Pre-Alpha",
        "Programming Language :: Python",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: BSD License",
        "Operating System :: POSIX",
        "Topic :: Utilities",
    ],
    keywords                = 'command line filesystem',
    author                  = 'Andreas Kaiser',
    author_email            = 'disko@binary-punks.com',
    url                     = 'http://github.com/disko/bp.rename',
    license                 = 'New BSD',
    packages                = find_packages(exclude=['ez_setup']),
    namespace_packages      = ['bp'],
    include_package_data    = True,
    zip_safe                = False,
    install_requires        = [
        'setuptools',
        # -*- Extra requirements: -*-
        'baker',
        'texttable',
    ],
    entry_points            = """
    # -*- Entry points: -*-
    [console_scripts]
    bp_rename = bp.rename:main
    """,
)
    